@@ -1,4 +1,4 @@
-package Dancer2::Template::Handlebars 0.2;
+package Dancer2::Template::Handlebars 0.3;
 
 # ABSTRACT: Dancer2 wrapper for Handlebars templating engine
 
@@ -85,11 +85,27 @@ Dancer2::Template::Handlebars - Dancer2 wrapper for Handlebars templating engine
 
 =head1 VERSION
 
-version 0.2
+version 0.3
 
 =head1 SYNOPSIS
 
-Dancer2 wrapper around Handlebars templating engine
+in your Dancer2 app config.yml:
+
+    template: "handlebars"
+
+...and if you want to add custom helpers:
+
+    engines:
+        handlebars:
+            helpers:
+                - MyApp::HandlebarsHelpers
+
+=head1 HELPERS
+
+You can create custom modules full of helpers to use in your Handlebars templates. For
+more details on creating these, see L<Dancer2::Template::Handlebars::Helpers>.
+
+Handlebars comes with helpers C<with>, C<each>, C<if>, and C<unless>.
 
 =head1 GRATEFUL THANKS
 
@@ -98,6 +114,40 @@ L<Dancer2::Template::Mustache>. Most all of the code you see in this
 module is his work, or very, very close to his original code; I
 merely remixed it, and got tests working for my own purposes.
 
+=head1 SEE ALSO
+
+L<http://handlebarsjs.com>
+
+L<Text::Handlebars>
+
+=head1 SUPPORT
+
+You can find this documentation for this module with the perldoc command.
+
+    perldoc Dancer2::Template::Handlebars
+
+You can also look for information at:
+
+=over 4
+
+=item * MetaCPAN
+
+L<https://metacpan.org/release/Dancer2-Template-Handlebars>
+
+=item * Gitlab
+
+L<https://gitlab.com/GeekRuthie/dancer2-template-handlebars>
+
+=item * Gitlab issues tracker
+
+L<https://gitlab.com/GeekRuthie/dancer2-template-handlebars/-/issues>
+
+=item * CPAN Ratings
+
+L<http://cpanratings.perl.org/d/Dancer2-Template-Handlebars>
+
+=back
+
 =head1 AUTHOR
 
 Ruth Holloway <ruth@hiruthie.me>
